@@ -94,7 +94,7 @@ class _CreateCategoricalEncodedVariables(DoFn):
         with open('load_state_ohe.pkl', 'rb') as f:
             state_ohe = pickle.load(f)
 
-        download_blob("load_transforms", "load_city_lbe.pkl", "load_state_lbe.pkl")
+        download_blob("load_transforms", "load_city_lbe.pkl", "load_city_lbe.pkl")
         with open('load_city_lbe.pkl', 'rb') as f:
             city_lbe = pickle.load(f)
 
